@@ -1,12 +1,12 @@
 import logging
 import sys
 from logging import Formatter
-from logging.handlers import (BufferingHandler, RotatingFileHandler,
-                              SysLogHandler)
+from logging.handlers import BufferingHandler, RotatingFileHandler, SysLogHandler
 from typing import Any, Dict
 
 from freqtrade.exceptions import OperationalException
 
+
 logger = logging.getLogger(__name__)
 LOGFORMAT = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
 
