@@ -4,14 +4,15 @@ from pathlib import Path
 from typing import Any, Dict, List, Union
 
 from arrow import Arrow
-from pandas import DataFrame
 from numpy import int64
+from pandas import DataFrame
 from tabulate import tabulate
 
 from freqtrade.constants import DATETIME_PRINT_FORMAT, LAST_BT_RESULT_FN
-from freqtrade.data.btanalysis import calculate_max_drawdown, calculate_market_change
+from freqtrade.data.btanalysis import calculate_market_change, calculate_max_drawdown
 from freqtrade.misc import file_dump_json
 
+
 logger = logging.getLogger(__name__)
 
 
